@@ -2,17 +2,13 @@ package Data::Range::Compare::Stream;
 
 use strict;
 use warnings;
-use overload '""'=>\&to_string,fallback=>1;
+
+use base qw(Data::Range::Compare::Stream::Result::Base);
 use Data::Range::Compare::Stream::Constants qw(RANGE_START RANGE_END RANGE_DATA);
 
 use constant NEW_FROM_CLASS=>'Data::Range::Compare::Stream';
 
-our $VERSION='2.020';
-
-sub new {
-  my ($class,@args)=@_;
-  bless [@args],$class;
-}
+our $VERSION='3.021';
 
 sub to_string {
   my $notation=join ' - ',$_[0]->range_start_to_string,$_[0]->range_end_to_string;
@@ -25,6 +21,8 @@ sub range_end () { $_[0]->[RANGE_END] }
 sub range_start_to_string () { $_[0]->range_start }
 sub range_end_to_string () { $_[0]->range_end }
 
+sub on_create_range { }
+
 sub add_one ($) {
   my ($self,$value)=@_;
   $value + 1;
@@ -41,6 +39,7 @@ sub cmp_values ($$) {
 }
 
 sub next_range_start () { $_[0]->add_one($_[0]->range_end)  }
+
 sub previous_range_end () { $_[0]->sub_one($_[0]->range_start)  }
 
 sub data {
@@ -59,7 +58,11 @@ sub get_common_range ($) {
     $range_end=$ranges->[$x] if $class->cmp_values($range_end->range_end,$ranges->[$x]->range_end)==1;
   }
 
-  $class->NEW_FROM_CLASS->new($range_start->range_start,$range_end->range_end);
+  my $new_range=$class->NEW_FROM_CLASS->new($range_start->range_start,$range_end->range_end);
+
+  $new_range->on_create_range($range_start);
+
+  $new_range;
 }
 
 sub find_smallest_outer_ranges {
@@ -98,7 +101,9 @@ sub get_overlapping_range ($) {
     $range_end=$ranges->[$x] if $class->cmp_values($range_end->range_end,$ranges->[$x]->range_end)==-1;
   }
 
-  $class->NEW_FROM_CLASS->new($range_start->range_start,$range_end->range_end);
+  my $new_range=$class->NEW_FROM_CLASS->new($range_start->range_start,$range_end->range_end);
+  $new_range->on_create_range($range_start);
+  $new_range;
 }
 
 
